#!/usr/bin/python3

import matplotlib.pyplot as plt
import at as pa
# Define the particle beam
particle_type = pa.ParticleType.proton
particle_energy = 10e6  # MeV
beam_sigma = 0.5e-3  # m

# Create the particle beam
proton_beam = pa.ParticleBeam(particle_type, particle_energy, 1, beam_sigma)
# Define the magnetic elements
dipole_length = 0.1  # m
dipole_strength = 0.1  # Tm
quadrupole_length = 0.05  # m
quadrupole_strength = 1  # T/m

# Create the dipole magnet
dipole = pa.Dipole(dipole_length, dipole_strength)

# Create the quadrupole magnet
quadrupole = pa.Quadrupole(quadrupole_length, quadrupole_strength)
# Define the number of particles and the tracking steps
n_particles = 100
n_steps = 10

# Track the particles through the magnetic elements
tracker = pa.Tracker(dipole, quadrupole)
tracked_particles = tracker.track(proton_beam, n_steps)


# Calculate the particle energies
particle_energies = tracked_particles.x[-1] * proton_beam.energy / beam_sigma

# Create a histogram of the particle energies
plt.hist(particle_energies, bins=50, density=True)
plt.xlabel("Particle Energy (MeV)")
plt.ylabel("Probability Density")
plt.show()

